@@ -19,7 +19,6 @@ import time
 from datetime import datetime
 
 from twisted.internet import defer
-from twisted.internet import reactor
 from twisted.python import log
 from twisted.web import client
 
@@ -124,7 +123,7 @@ class BitbucketPullrequestPoller(base.PollingChangeSource):
                             pr['updated_on'].split('.')[0],
                             '%Y-%m-%dT%H:%M:%S')
                     else:
-                        updated = epoch2datetime(reactor.seconds())
+                        updated = epoch2datetime(self.master.reactor.seconds())
                     title = pr['title']
                     # parse commit api page
                     page = yield client.getPage(str(pr['source']['commit']['links']['self']['href']))
@@ -142,6 +141,7 @@ class BitbucketPullrequestPoller(base.PollingChangeSource):
                     # emit the change
                     yield self.master.data.updates.addChange(
                         author=bytes2unicode(author),
+                        committer=None,
                         revision=bytes2unicode(revision),
                         revlink=bytes2unicode(revlink),
                         comments='pull-request #%d: %s\n%s' % (
