@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from future.utils import string_types
-from future.utils import text_type
-
 import datetime
 import inspect
 import os
@@ -231,6 +228,7 @@ class MasterConfig(util.ComparableMixin):
         self.builders = []
         self.workers = []
         self.change_sources = []
+        self.machines = []
         self.status = []
         self.user_managers = []
         self.revlink = default_revlink_matcher
@@ -266,6 +264,7 @@ class MasterConfig(util.ComparableMixin):
         "logMaxSize",
         "logMaxTailSize",
         "manhole",
+        "machines",
         "collapseRequests",
         "metrics",
         "mq",
@@ -341,6 +340,7 @@ class MasterConfig(util.ComparableMixin):
             config.load_builders(filename, config_dict)
             config.load_workers(filename, config_dict)
             config.load_change_sources(filename, config_dict)
+            config.load_machines(filename, config_dict)
             config.load_user_managers(filename, config_dict)
             config.load_www(filename, config_dict)
             config.load_services(filename, config_dict)
@@ -351,6 +351,7 @@ class MasterConfig(util.ComparableMixin):
             config.check_locks()
             config.check_builders()
             config.check_ports()
+            config.check_machines()
         finally:
             _errors = None
 
@@ -385,7 +386,7 @@ class MasterConfig(util.ComparableMixin):
 
         def copy_str_param(name, alt_key=None):
             copy_param(name, alt_key=alt_key,
-                       check_type=string_types, check_type_name='a string')
+                       check_type=(str,), check_type_name='a string')
 
         copy_str_param('title', alt_key='projectName')
         copy_str_param('titleURL', alt_key='projectURL')
@@ -393,7 +394,7 @@ class MasterConfig(util.ComparableMixin):
 
         def copy_str_or_callable_param(name, alt_key=None):
             copy_param(name, alt_key=alt_key,
-                       check_type=string_types, check_type_name='a string or callable', can_be_callable=True)
+                       check_type=(str,), check_type_name='a string or callable', can_be_callable=True)
 
         if "buildbotNetUsageData" not in config_dict:
             if _in_unit_tests:
@@ -696,23 +697,14 @@ class MasterConfig(util.ComparableMixin):
         return True
 
     def load_workers(self, filename, config_dict):
-        config_valid = True
-
         workers = config_dict.get('workers')
-        if workers is not None:
-            if not self._check_workers(workers, "c['workers']"):
-                config_valid = False
-
-        if not config_valid:
+        if workers is None:
             return
 
-        elif workers is not None:
-            self.workers = []
-            if workers is not None:
-                self.workers.extend(workers)
+        if not self._check_workers(workers, "c['workers']"):
+            return
 
-        else:
-            pass
+        self.workers = workers[:]
 
     def load_change_sources(self, filename, config_dict):
         change_source = config_dict.get('change_source', [])
@@ -729,6 +721,23 @@ class MasterConfig(util.ComparableMixin):
 
         self.change_sources = change_sources
 
+    def load_machines(self, filename, config_dict):
+        if 'machines' not in config_dict:
+            return
+
+        machines = config_dict['machines']
+        msg = "c['machines'] must be a list of machines"
+        if not isinstance(machines, (list, tuple)):
+            error(msg)
+            return
+
+        for m in machines:
+            if not interfaces.IMachine.providedBy(m):
+                error(msg)
+                return
+
+        self.machines = machines
+
     def load_user_managers(self, filename, config_dict):
         if 'user_managers' not in config_dict:
             return
@@ -905,6 +914,19 @@ class MasterConfig(util.ComparableMixin):
         if self.workers:
             error("workers are configured, but c['protocols'] not")
 
+    def check_machines(self):
+        seen_names = set()
+
+        for mm in self.machines:
+            if mm.name in seen_names:
+                error("duplicate machine name '{}'".format(mm.name))
+            seen_names.add(mm.name)
+
+        for w in self.workers:
+            if w.machine_name is not None and w.machine_name not in seen_names:
+                error("worker '{}' uses unknown machine '{}'".format(
+                    w.name, w.machine_name))
+
 
 class BuilderConfig(util_config.ConfiguredMixin):
 
@@ -916,7 +938,7 @@ class BuilderConfig(util_config.ConfiguredMixin):
                  canStartBuild=None, defaultProperties=None
                  ):
         # name is required, and can't start with '_'
-        if not name or type(name) not in (bytes, text_type):
+        if not name or type(name) not in (bytes, str):
             error("builder's name is required")
             name = '<unknown>'
         elif name[0] == '_' and name not in RESERVED_UNDERSCORE_NAMES:
