@@ -34,6 +34,7 @@ from buildbot.changes.manager import ChangeManager
 from buildbot.data import connector as dataconnector
 from buildbot.db import connector as dbconnector
 from buildbot.db import exceptions
+from buildbot.machine.manager import MachineManager
 from buildbot.mq import connector as mqconnector
 from buildbot.process import cache
 from buildbot.process import debug
@@ -83,7 +84,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             raise config.ConfigErrors([
                 "Can't specify both `config_loader` and `configFilename`.",
             ])
-        elif config_loader is None:
+        if config_loader is None:
             if configFileName is None:
                 configFileName = 'master.cfg'
             config_loader = config.FileLoader(self.basedir, configFileName)
@@ -102,6 +103,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
 
         # configuration / reconfiguration handling
         self.config = config.MasterConfig()
+        self.config_version = 0  # increased by one on each reconfig
         self.reconfig_active = False
         self.reconfig_requested = False
         self.reconfig_notifier = None
@@ -151,6 +153,9 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         self.botmaster = BotMaster()
         self.botmaster.setServiceParent(self)
 
+        self.machine_manager = MachineManager()
+        self.machine_manager.setServiceParent(self)
+
         self.scheduler_manager = SchedulerManager()
         self.scheduler_manager.setServiceParent(self)
 
@@ -338,6 +343,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         finally:
             yield self.initLock.release()
 
+    @defer.inlineCallbacks
     def reconfig(self):
         # this method wraps doConfig, ensuring it is only ever called once at
         # a time, and alerting the user if the reconfig takes too long
@@ -359,10 +365,11 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         timer = metrics.Timer("BuildMaster.reconfig")
         timer.start()
 
-        d = self.doReconfig()
-
-        @d.addBoth
-        def cleanup(res):
+        try:
+            yield self.doReconfig()
+        except Exception as e:
+            log.err(e, 'while reconfiguring')
+        finally:
             timer.stop()
             self.reconfig_notifier.stop()
             self.reconfig_notifier = None
@@ -370,11 +377,6 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             if self.reconfig_requested:
                 self.reconfig_requested = False
                 self.reconfig()
-            return res
-
-        d.addErrback(log.err, 'while reconfiguring')
-
-        return d  # for tests
 
     @defer.inlineCallbacks
     def doReconfig(self):
@@ -388,6 +390,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
                 self.reactor, self.reactor.getThreadPool(),
                 self.config_loader.loadConfig)
             changes_made = True
+            self.config_version += 1
             self.config = new_config
 
             yield self.reconfigServiceWithBuildbotConfig(new_config)
