@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from future.utils import string_types
-
 import warnings
 import weakref
 
@@ -39,7 +37,7 @@ from buildbot.util import service as util_service
 def enforceChosenWorker(bldr, workerforbuilder, breq):
     if 'workername' in breq.properties:
         workername = breq.properties['workername']
-        if isinstance(workername, string_types):
+        if isinstance(workername, str):
             return workername == workerforbuilder.worker.workername
 
     return True
@@ -80,6 +78,9 @@ class Builder(util_service.ReconfigurableServiceMixin,
         self.config = None
         self.builder_status = None
 
+        # Tracks config version for locks
+        self.config_version = None
+
     @defer.inlineCallbacks
     def reconfigServiceWithBuildbotConfig(self, new_config):
         # find this builder in the config
@@ -98,6 +99,7 @@ class Builder(util_service.ReconfigurableServiceMixin,
                 description=builder_config.description)
 
         self.config = builder_config
+        self.config_version = self.master.config_version
 
         # allocate  builderid now, so that the builder is visible in the web
         # UI; without this, the builder wouldn't appear until it preformed a
@@ -297,8 +299,8 @@ class Builder(util_service.ReconfigurableServiceMixin,
             props = setupPropsIfNeeded(props)
             locks = yield props.render(locks)
 
-        locks = [(self.botmaster.getLockFromLockAccess(access), access)
-                 for access in locks]
+        locks = yield self.botmaster.getLockFromLockAccesses(locks, self.config_version)
+
         if locks:
             can_start = Build._canAcquireLocks(locks, workerforbuilder)
             if can_start is False:
