@@ -78,7 +78,7 @@ class Properties(util.ComparableMixin):
     @property
     def sourcestamps(self):
         if self.build is not None:
-            return [b.asSSDict() for b in self.build.getAllSourceStamps()]
+            return [b.asDict() for b in self.build.getAllSourceStamps()]
         elif self._sourcestamps is not None:
             return self._sourcestamps
         raise AttributeError('neither build nor _sourcestamps are set')
@@ -87,6 +87,12 @@ class Properties(util.ComparableMixin):
     def sourcestamps(self, value):
         self._sourcestamps = value
 
+    def getSourceStamp(self, codebase=''):
+        for source in self.sourcestamps:
+            if source['codebase'] == codebase:
+                return source
+        return None
+
     @property
     def changes(self):
         if self.build is not None:
@@ -148,7 +154,7 @@ class Properties(util.ComparableMixin):
     def asDict(self):
         """Return the properties as a simple key:value dictionary,
         properly unicoded"""
-        return dict((k, (v, s)) for k, (v, s) in self.properties.items())
+        return self.properties.copy()
 
     def __repr__(self):
         return ('Properties(**' +
@@ -184,7 +190,8 @@ class Properties(util.ComparableMixin):
 
     def setProperty(self, name, value, source, runtime=False):
         name = util.bytes2unicode(name)
-        json.dumps(value)  # Let the exception propagate ...
+        if not IRenderable.providedBy(value):
+            json.dumps(value)  # Let the exception propagate ...
         source = util.bytes2unicode(source)
 
         self.properties[name] = (value, source)
@@ -478,24 +485,7 @@ class _SecretRenderer:
 class Secret(_SecretRenderer):
 
     def __repr__(self):
-        return "Secret({0})".format(self.secretKey)
-
-    def __init__(self, secretKey):
-        self.secretKey = secretKey
-
-    @defer.inlineCallbacks
-    def getRenderingFor(self, props):
-        secretsSrv = props.master.namedServices.get("secrets")
-        if not secretsSrv:
-            error_message = "secrets service not started, need to configure" \
-                            " SecretManager in c['services'] to use 'secrets'" \
-                            "in Interpolate"
-            raise KeyError(error_message)
-        credsservice = props.master.namedServices['secrets']
-        secret_detail = yield credsservice.get(self.secretKey)
-        if secret_detail is None:
-            raise KeyError("secret key %s is not found in any provider" % self.secretKey)
-        return secret_detail.value
+        return "Secret({0})".format(self.secret_name)
 
 
 class _SecretIndexer:
@@ -515,10 +505,10 @@ class _SourceStampDict(util.ComparableMixin):
     def __init__(self, codebase):
         self.codebase = codebase
 
-    def getRenderingFor(self, build):
-        ss = build.getBuild().getSourceStamp(self.codebase)
+    def getRenderingFor(self, props):
+        ss = props.getSourceStamp(self.codebase)
         if ss:
-            return ss.asDict()
+            return ss
         return {}
 
 
