@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from future.utils import string_types
-
 import re
 import traceback
 
@@ -143,7 +141,7 @@ class BaseParameter:
 
         # delete white space for args
         for arg in args:
-            if isinstance(arg, string_types) and not arg.strip():
+            if isinstance(arg, str) and not arg.strip():
                 args.remove(arg)
 
         if not args:
@@ -549,7 +547,7 @@ class CodebaseParameter(NestedParameter):
         for k, v in fields_dict.items():
             if v is DefaultField:
                 v = StringParameter(name=k, label=k.capitalize() + ":")
-            elif isinstance(v, string_types):
+            elif isinstance(v, str):
                 v = FixedParameter(name=k, default=v)
             fields_dict[k] = v
 
@@ -680,7 +678,7 @@ class ForceScheduler(base.BaseScheduler):
             config.error("ForceScheduler name must be an identifier: %r" %
                          name)
 
-        if not self.checkIfListOfType(builderNames, string_types):
+        if not self.checkIfListOfType(builderNames, (str,)):
             config.error("ForceScheduler '%s': builderNames must be a list of strings: %r" %
                          (name, builderNames))
 
@@ -719,7 +717,7 @@ class ForceScheduler(base.BaseScheduler):
 
         codebase_dict = {}
         for codebase in codebases:
-            if isinstance(codebase, string_types):
+            if isinstance(codebase, str):
                 codebase = CodebaseParameter(codebase=codebase)
             elif not isinstance(codebase, CodebaseParameter):
                 config.error("ForceScheduler '%s': 'codebases' must be a list of strings"
