@@ -21,26 +21,31 @@ from twisted.trial import unittest
 from buildbot.changes import hgpoller
 from buildbot.test.util import changesource
 from buildbot.test.util import gpo
+from buildbot.test.util.misc import TestReactorMixin
 
 ENVIRON_2116_KEY = 'TEST_THAT_ENVIRONMENT_GETS_PASSED_TO_SUBPROCESSES'
 LINESEP_BYTES = os.linesep.encode("ascii")
 PATHSEP_BYTES = os.pathsep.encode("ascii")
 
 
-class TestHgPoller(gpo.GetProcessOutputMixin,
-                   changesource.ChangeSourceMixin,
-                   unittest.TestCase):
+class TestHgPollerBase(gpo.GetProcessOutputMixin,
+                       changesource.ChangeSourceMixin,
+                       TestReactorMixin,
+                       unittest.TestCase):
     usetimestamps = True
+    branches = None
+    bookmarks = None
 
     @defer.inlineCallbacks
     def setUp(self):
+        self.setUpTestReactor()
+
         # To test that environment variables get propagated to subprocesses
         # (See #2116)
         os.environ[ENVIRON_2116_KEY] = 'TRUE'
         self.setUpGetProcessOutput()
         yield self.setUpChangeSource()
         self.remote_repo = 'ssh://example.com/foo/baz'
-        self.branch = 'default'
         self.repo_ready = True
 
         def _isRepositoryReady():
@@ -48,12 +53,167 @@ class TestHgPoller(gpo.GetProcessOutputMixin,
 
         self.poller = hgpoller.HgPoller(self.remote_repo,
                                         usetimestamps=self.usetimestamps,
-                                        workdir='/some/dir')
+                                        workdir='/some/dir',
+                                        branches=self.branches,
+                                        bookmarks=self.bookmarks)
         self.poller.setServiceParent(self.master)
         self.poller._isRepositoryReady = _isRepositoryReady
 
         yield self.master.db.setup()
 
+    @defer.inlineCallbacks
+    def check_current_rev(self, wished, branch='default'):
+        rev = yield self.poller._getCurrentRev(branch)
+        self.assertEqual(rev, str(wished))
+
+
+class TestHgPollerBranches(TestHgPollerBase):
+    branches = ['one', 'two']
+
+    @defer.inlineCallbacks
+    def test_poll_initial(self):
+        self.expectCommands(
+            gpo.Expect('hg', 'pull', '-b', 'one', '-b', 'two',
+                       'ssh://example.com/foo/baz')
+            .path('/some/dir'),
+            gpo.Expect(
+                'hg', 'heads', '-r', 'one', '--template={rev}' + os.linesep)
+            .path('/some/dir').stdout(b"73591"),
+            gpo.Expect(
+                'hg', 'heads', '-r', 'two', '--template={rev}' + os.linesep)
+            .path('/some/dir').stdout(b"22341"),
+        )
+
+        # do the poll
+        yield self.poller.poll()
+
+        # check the results
+        self.assertEqual(len(self.master.data.updates.changesAdded), 0)
+
+        yield self.check_current_rev(73591, 'one')
+        yield self.check_current_rev(22341, 'two')
+
+    @defer.inlineCallbacks
+    def test_poll_regular(self):
+        # normal operation. There's a previous revision, we get a new one.
+        # Let's say there was an intervening commit on an untracked branch, to
+        # make it more interesting.
+        self.expectCommands(
+            gpo.Expect('hg', 'pull', '-b', 'one', '-b', 'two',
+                       'ssh://example.com/foo/baz')
+            .path('/some/dir'),
+            gpo.Expect(
+                'hg', 'heads', '-r', 'one', '--template={rev}' + os.linesep)
+            .path('/some/dir').stdout(b'6' + LINESEP_BYTES),
+            gpo.Expect('hg', 'log', '-r', '4::6',
+                       '--template={rev}:{node}\\n')
+            .path('/some/dir').stdout(LINESEP_BYTES.join([
+                        b'4:1aaa5',
+                        b'6:784bd',
+                    ])),
+            gpo.Expect('hg', 'log', '-r', '784bd',
+                       '--template={date|hgdate}' + os.linesep +
+                       '{author}' + os.linesep +
+                       "{files % '{file}" +
+                       os.pathsep + "'}" +
+                       os.linesep + '{desc|strip}')
+            .path('/some/dir').stdout(LINESEP_BYTES.join([
+                b'1273258009.0 -7200',
+                b'Joe Test <joetest@example.org>',
+                b'file1 file2',
+                b'Comment',
+                b''])),
+            gpo.Expect(
+                'hg', 'heads', '-r', 'two', '--template={rev}' + os.linesep)
+            .path('/some/dir').stdout(b'3' + LINESEP_BYTES),
+        )
+
+        yield self.poller._setCurrentRev(3, 'two')
+        yield self.poller._setCurrentRev(4, 'one')
+
+        yield self.poller.poll()
+        yield self.check_current_rev(6, 'one')
+
+        self.assertEqual(len(self.master.data.updates.changesAdded), 1)
+        change = self.master.data.updates.changesAdded[0]
+        self.assertEqual(change['revision'], '784bd')
+        self.assertEqual(change['comments'], 'Comment')
+
+
+class TestHgPollerBookmarks(TestHgPollerBase):
+    bookmarks = ['one', 'two']
+
+    @defer.inlineCallbacks
+    def test_poll_initial(self):
+        self.expectCommands(
+            gpo.Expect('hg', 'pull', '-B', 'one', '-B', 'two',
+                       'ssh://example.com/foo/baz')
+            .path('/some/dir'),
+            gpo.Expect(
+                'hg', 'heads', '-r', 'one', '--template={rev}' + os.linesep)
+            .path('/some/dir').stdout(b"73591"),
+            gpo.Expect(
+                'hg', 'heads', '-r', 'two', '--template={rev}' + os.linesep)
+            .path('/some/dir').stdout(b"22341"),
+        )
+
+        # do the poll
+        yield self.poller.poll()
+
+        # check the results
+        self.assertEqual(len(self.master.data.updates.changesAdded), 0)
+
+        yield self.check_current_rev(73591, 'one')
+        yield self.check_current_rev(22341, 'two')
+
+    @defer.inlineCallbacks
+    def test_poll_regular(self):
+        # normal operation. There's a previous revision, we get a new one.
+        # Let's say there was an intervening commit on an untracked branch, to
+        # make it more interesting.
+        self.expectCommands(
+            gpo.Expect('hg', 'pull', '-B', 'one', '-B', 'two',
+                       'ssh://example.com/foo/baz')
+            .path('/some/dir'),
+            gpo.Expect(
+                'hg', 'heads', '-r', 'one', '--template={rev}' + os.linesep)
+            .path('/some/dir').stdout(b'6' + LINESEP_BYTES),
+            gpo.Expect('hg', 'log', '-r', '4::6',
+                       '--template={rev}:{node}\\n')
+            .path('/some/dir').stdout(LINESEP_BYTES.join([
+                        b'4:1aaa5',
+                        b'6:784bd',
+                    ])),
+            gpo.Expect('hg', 'log', '-r', '784bd',
+                       '--template={date|hgdate}' + os.linesep +
+                       '{author}' + os.linesep +
+                       "{files % '{file}" +
+                       os.pathsep + "'}" +
+                       os.linesep + '{desc|strip}')
+            .path('/some/dir').stdout(LINESEP_BYTES.join([
+                b'1273258009.0 -7200',
+                b'Joe Test <joetest@example.org>',
+                b'file1 file2',
+                b'Comment',
+                b''])),
+            gpo.Expect(
+                'hg', 'heads', '-r', 'two', '--template={rev}' + os.linesep)
+            .path('/some/dir').stdout(b'3' + LINESEP_BYTES),
+        )
+
+        yield self.poller._setCurrentRev(3, 'two')
+        yield self.poller._setCurrentRev(4, 'one')
+
+        yield self.poller.poll()
+        yield self.check_current_rev(6, 'one')
+
+        self.assertEqual(len(self.master.data.updates.changesAdded), 1)
+        change = self.master.data.updates.changesAdded[0]
+        self.assertEqual(change['revision'], '784bd')
+        self.assertEqual(change['comments'], 'Comment')
+
+
+class TestHgPoller(TestHgPollerBase):
     def tearDown(self):
         del os.environ[ENVIRON_2116_KEY]
         return self.tearDownChangeSource()
@@ -73,8 +233,7 @@ class TestHgPoller(gpo.GetProcessOutputMixin,
         self.assertSubstring("HgPoller", self.poller.describe())
 
     def test_name(self):
-        self.assertEqual(
-            "%s[%s]" % (self.remote_repo, self.branch), self.poller.name)
+        self.assertEqual(self.remote_repo, self.poller.name)
 
         # and one with explicit name...
         other = hgpoller.HgPoller(
@@ -97,52 +256,18 @@ class TestHgPoller(gpo.GetProcessOutputMixin,
                        'ssh://example.com/foo/baz')
             .path('/some/dir'),
             gpo.Expect(
-                'hg', 'heads', 'default', '--template={rev}' + os.linesep)
+                'hg', 'heads', '-r', 'default', '--template={rev}' + os.linesep)
             .path('/some/dir').stdout(b"73591"),
-            gpo.Expect('hg', 'log', '-b', 'default', '-r', '73591:73591',  # only fetches that head
-                       '--template={rev}:{node}\\n')
-            .path('/some/dir').stdout(LINESEP_BYTES.join([b'73591:4423cdb'])),
-            gpo.Expect('hg', 'log', '-r', '4423cdb',
-                       '--template={date|hgdate}' + os.linesep + \
-                       '{author}' + os.linesep + \
-                       "{files % '{file}" + os.pathsep + \
-                       "'}" + os.linesep + '{desc|strip}')
-            .path('/some/dir').stdout(LINESEP_BYTES.join([
-                b'1273258100.0 -7200',
-                b'Bob Test <bobtest@example.org>',
-                b'file1 with spaces' + PATHSEP_BYTES +
-                os.path.join(b'dir with spaces', b'file2') + PATHSEP_BYTES,
-                b'This is rev 73591',
-                b''])),
         )
 
         # do the poll
         yield self.poller.poll()
 
         # check the results
-        self.assertEqual(len(self.master.data.updates.changesAdded), 1)
-
-        change = self.master.data.updates.changesAdded[0]
-        self.assertEqual(change['revision'], '4423cdb')
-        self.assertEqual(change['author'],
-                         'Bob Test <bobtest@example.org>')
-        if self.usetimestamps:
-            self.assertEqual(change['when_timestamp'], 1273258100)
-        else:
-            self.assertEqual(change['when_timestamp'], None)
-        self.assertEqual(
-            change['files'], ['file1 with spaces', os.path.join('dir with spaces', 'file2')])
-        self.assertEqual(change['src'], 'hg')
-        self.assertEqual(change['branch'], 'default')
-        self.assertEqual(change['comments'], 'This is rev 73591')
+        self.assertEqual(len(self.master.data.updates.changesAdded), 0)
 
         yield self.check_current_rev(73591)
 
-    @defer.inlineCallbacks
-    def check_current_rev(self, wished):
-        oid_rev = yield self.poller._getCurrentRev()
-        self.assertEqual(oid_rev[1], wished)
-
     @defer.inlineCallbacks
     def test_poll_several_heads(self):
         # If there are several heads on the named branch, the poller mustn't
@@ -153,7 +278,7 @@ class TestHgPoller(gpo.GetProcessOutputMixin,
                        'ssh://example.com/foo/baz')
             .path('/some/dir'),
             gpo.Expect(
-                'hg', 'heads', 'default', '--template={rev}' + os.linesep)
+                'hg', 'heads', '-r', 'default', '--template={rev}' + os.linesep)
             .path('/some/dir').stdout(b'5' + LINESEP_BYTES + b'6' + LINESEP_BYTES)
         )
 
@@ -171,11 +296,14 @@ class TestHgPoller(gpo.GetProcessOutputMixin,
                        'ssh://example.com/foo/baz')
             .path('/some/dir'),
             gpo.Expect(
-                'hg', 'heads', 'default', '--template={rev}' + os.linesep)
+                'hg', 'heads', '-r', 'default', '--template={rev}' + os.linesep)
             .path('/some/dir').stdout(b'5' + LINESEP_BYTES),
-            gpo.Expect('hg', 'log', '-b', 'default', '-r', '5:5',
+            gpo.Expect('hg', 'log', '-r', '4::5',
                        '--template={rev}:{node}\\n')
-            .path('/some/dir').stdout(b'5:784bd' + LINESEP_BYTES),
+            .path('/some/dir').stdout(LINESEP_BYTES.join([
+                        b'4:1aaa5',
+                        b'5:784bd',
+                    ])),
             gpo.Expect('hg', 'log', '-r', '784bd',
                        '--template={date|hgdate}' + os.linesep +
                        '{author}' + os.linesep +
