@@ -39,6 +39,7 @@ from buildbot.test.fake import fakemaster
 from buildbot.test.fake import fakeprotocol
 from buildbot.test.fake import worker
 from buildbot.test.fake.fakebuild import FakeBuildStatus
+from buildbot.test.util.misc import TestReactorMixin
 
 
 class FakeChange:
@@ -110,6 +111,7 @@ class FakeBuilder:
         self.botmaster = master.botmaster
         self.builderid = 83
         self._builders = {}
+        self.config_version = 0
 
     def getBuilderId(self):
         return defer.succeed(self.builderid)
@@ -174,16 +176,17 @@ def makeControllableStepFactory():
     return controller, FakeStepFactory(step)
 
 
-class TestBuild(unittest.TestCase):
+class TestBuild(TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         r = FakeRequest()
         r.sources = [FakeSource()]
         r.sources[0].changes = [FakeChange()]
         r.sources[0].revision = "12345"
 
         self.request = r
-        self.master = fakemaster.make_master(wantData=True, testcase=self)
+        self.master = fakemaster.make_master(self, wantData=True)
 
         self.worker = worker.FakeWorker(self.master)
         self.worker.attached(None)
@@ -200,6 +203,10 @@ class TestBuild(unittest.TestCase):
         self.build.text = []
         self.build.buildid = 666
 
+    def assertWorkerPreparationFailure(self, reason):
+        states = "".join(self.master.data.updates.stepStateString.values())
+        self.assertIn(states, reason)
+
     def testRunSuccessfulBuild(self):
         b = self.build
 
@@ -237,6 +244,7 @@ class TestBuild(unittest.TestCase):
         self.workerforbuilder.prepare = lambda _: False
         b.startBuild(FakeBuildStatus(), self.workerforbuilder)
         self.assertEqual(b.results, RETRY)
+        self.assertWorkerPreparationFailure('error while worker_prepare')
 
     def testBuildCancelledWhenWorkerPrepareReturnFalseBecauseBuildStop(self):
         b = self.build
@@ -250,6 +258,7 @@ class TestBuild(unittest.TestCase):
         b.stopBuild('Cancel Build', CANCELLED)
         d.callback(False)
         self.assertEqual(b.results, CANCELLED)
+        self.assertWorkerPreparationFailure('error while worker_prepare')
 
     def testBuildRetryWhenWorkerPrepareReturnFalseBecauseBuildStop(self):
         b = self.build
@@ -263,6 +272,7 @@ class TestBuild(unittest.TestCase):
         b.stopBuild('Cancel Build', RETRY)
         d.callback(False)
         self.assertEqual(b.results, RETRY)
+        self.assertWorkerPreparationFailure('error while worker_prepare')
 
     @defer.inlineCallbacks
     def testAlwaysRunStepStopBuild(self):
@@ -305,6 +315,7 @@ class TestBuild(unittest.TestCase):
         self.assertIn('stop it', step1.interrupted)
         self.assertTrue(step2Started[0])
 
+    @defer.inlineCallbacks
     def testBuild_canAcquireLocks(self):
         b = self.build
 
@@ -313,7 +324,8 @@ class TestBuild(unittest.TestCase):
 
         lock = WorkerLock('lock')
         counting_access = lock.access('counting')
-        real_lock = b.builder.botmaster.getLockByID(lock)
+
+        real_lock = yield b.builder.botmaster.getLockByID(lock, 0)
 
         # no locks, so both these pass (call twice to verify there's no
         # state/memory)
@@ -376,6 +388,7 @@ class TestBuild(unittest.TestCase):
             [call('builddir', expected_path, 'Worker')],
             any_order=True)
 
+    @defer.inlineCallbacks
     def testBuildLocksAcquired(self):
         b = self.build
 
@@ -383,15 +396,16 @@ class TestBuild(unittest.TestCase):
         claimCount = [0]
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
-        real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLockForWorker(self.workerforbuilder.worker.workername)
+
+        real_workerlock = yield b.builder.botmaster.getLockByID(lock, 0)
+        real_lock = real_workerlock.getLockForWorker(self.workerforbuilder.worker.workername)
 
         def claim(owner, access):
             claimCount[0] += 1
             return real_lock.old_claim(owner, access)
         real_lock.old_claim = real_lock.claim
         real_lock.claim = claim
-        b.setLocks([lock_access])
+        yield b.setLocks([lock_access])
 
         step = FakeBuildStep()
         b.setStepFactories([FakeStepFactory(step)])
@@ -401,11 +415,11 @@ class TestBuild(unittest.TestCase):
         self.assertEqual(b.results, SUCCESS)
         self.assertEqual(claimCount[0], 1)
 
+    @defer.inlineCallbacks
     def testBuildLocksOrder(self):
         """Test that locks are acquired in FIFO order; specifically that
         counting locks cannot jump ahead of exclusive locks"""
         eBuild = self.build
-
         cBuilder = FakeBuilder(self.master)
         cBuild = Build([self.request])
         cBuild.setBuilder(cBuilder)
@@ -420,8 +434,9 @@ class TestBuild(unittest.TestCase):
 
         lock = WorkerLock('lock', 2)
         claimLog = []
-        realLock = self.master.botmaster.getLockByID(lock) \
-            .getLockForWorker(self.worker.workername)
+
+        real_workerlock = yield self.master.botmaster.getLockByID(lock, 0)
+        realLock = real_workerlock.getLockForWorker(self.worker.workername)
 
         def claim(owner, access):
             claimLog.append(owner)
@@ -429,8 +444,8 @@ class TestBuild(unittest.TestCase):
         realLock.oldClaim = realLock.claim
         realLock.claim = claim
 
-        eBuild.setLocks([lock.access('exclusive')])
-        cBuild.setLocks([lock.access('counting')])
+        yield eBuild.setLocks([lock.access('exclusive')])
+        yield cBuild.setLocks([lock.access('counting')])
 
         fakeBuild = Mock()
         fakeBuildAccess = lock.access('counting')
@@ -446,14 +461,12 @@ class TestBuild(unittest.TestCase):
 
         realLock.release(fakeBuild, fakeBuildAccess)
 
-        def check(ign):
-            self.assertEqual(eBuild.results, SUCCESS)
-            self.assertEqual(cBuild.results, SUCCESS)
-            self.assertEqual(claimLog, [fakeBuild, eBuild, cBuild])
-
-        d.addCallback(check)
-        return d
+        yield d
+        self.assertEqual(eBuild.results, SUCCESS)
+        self.assertEqual(cBuild.results, SUCCESS)
+        self.assertEqual(claimLog, [fakeBuild, eBuild, cBuild])
 
+    @defer.inlineCallbacks
     def testBuildWaitingForLocks(self):
         b = self.build
 
@@ -461,15 +474,16 @@ class TestBuild(unittest.TestCase):
         claimCount = [0]
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
-        real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLockForWorker(self.workerforbuilder.worker.workername)
+
+        real_workerlock = yield b.builder.botmaster.getLockByID(lock, 0)
+        real_lock = real_workerlock.getLockForWorker(self.workerforbuilder.worker.workername)
 
         def claim(owner, access):
             claimCount[0] += 1
             return real_lock.old_claim(owner, access)
         real_lock.old_claim = real_lock.claim
         real_lock.claim = claim
-        b.setLocks([lock_access])
+        yield b.setLocks([lock_access])
 
         step = FakeBuildStep()
         b.setStepFactories([FakeStepFactory(step)])
@@ -482,15 +496,18 @@ class TestBuild(unittest.TestCase):
         self.assertTrue(b.currentStep is None)
         self.assertTrue(b._acquiringLock is not None)
 
+    @defer.inlineCallbacks
     def testStopBuildWaitingForLocks(self):
         b = self.build
 
         lock = WorkerLock('lock')
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
-        real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLockForWorker(self.workerforbuilder.worker.workername)
-        b.setLocks([lock_access])
+
+        real_workerlock = yield b.builder.botmaster.getLockByID(lock, 0)
+        real_lock = real_workerlock.getLockForWorker(self.workerforbuilder.worker.workername)
+
+        yield b.setLocks([lock_access])
 
         step = FakeBuildStep()
         step.alwaysRun = False
@@ -509,15 +526,18 @@ class TestBuild(unittest.TestCase):
         self.assertTrue(b.currentStep is None)
         self.assertEqual(b.results, CANCELLED)
 
+    @defer.inlineCallbacks
     def testStopBuildWaitingForLocks_lostRemote(self):
         b = self.build
 
         lock = WorkerLock('lock')
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
-        real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLockForWorker(self.workerforbuilder.worker.workername)
-        b.setLocks([lock_access])
+
+        real_workerlock = yield b.builder.botmaster.getLockByID(lock, 0)
+        real_lock = real_workerlock.getLockForWorker(self.workerforbuilder.worker.workername)
+
+        yield b.setLocks([lock_access])
 
         step = FakeBuildStep()
         step.alwaysRun = False
@@ -539,14 +559,16 @@ class TestBuild(unittest.TestCase):
             ["retry", "lost", "connection"])
         self.build.build_status.setResults.assert_called_with(RETRY)
 
+    @defer.inlineCallbacks
     def testStopBuildWaitingForStepLocks(self):
         b = self.build
 
         lock = WorkerLock('lock')
         lock_access = lock.access('counting')
         lock.access = lambda mode: lock_access
-        real_lock = b.builder.botmaster.getLockByID(lock) \
-            .getLockForWorker(self.workerforbuilder.worker.workername)
+
+        real_workerlock = yield b.builder.botmaster.getLockByID(lock, 0)
+        real_lock = real_workerlock.getLockForWorker(self.workerforbuilder.worker.workername)
 
         step = LoggingBuildStep(locks=[lock_access])
         b.setStepFactories([FakeStepFactory(step)])
@@ -729,6 +751,7 @@ class TestBuild(unittest.TestCase):
             steps.append(step)
         return steps
 
+    @defer.inlineCallbacks
     def testAddStepsAfterCurrentStep(self):
         b = self.build
 
@@ -742,12 +765,13 @@ class TestBuild(unittest.TestCase):
         steps[1].startStep = startStepB
         b.setStepFactories([FakeStepFactory(s) for s in steps])
 
-        b.startBuild(FakeBuildStatus(), self.workerforbuilder)
+        yield b.startBuild(FakeBuildStatus(), self.workerforbuilder)
         self.assertEqual(b.results, SUCCESS)
         expected_names = ["a", "b", "d", "e", "c"]
         executed_names = [s.name for s in b.executedSteps]
         self.assertEqual(executed_names, expected_names)
 
+    @defer.inlineCallbacks
     def testAddStepsAfterLastStep(self):
         b = self.build
 
@@ -761,7 +785,7 @@ class TestBuild(unittest.TestCase):
         steps[1].startStep = startStepB
         b.setStepFactories([FakeStepFactory(s) for s in steps])
 
-        b.startBuild(FakeBuildStatus(), self.workerforbuilder)
+        yield b.startBuild(FakeBuildStatus(), self.workerforbuilder)
         self.assertEqual(b.results, SUCCESS)
         expected_names = ["a", "b", "c", "d", "e"]
         executed_names = [s.name for s in b.executedSteps]
@@ -822,6 +846,7 @@ class TestBuild(unittest.TestCase):
         # Let's fake a virtual builder
         self.builder._builders['wilma'] = 108
         self.build.setProperty('virtual_builder_name', 'wilma', 'Build')
+        self.build.setProperty('virtual_builder_tags', ['_virtual_'])
         self.build.number = 33
         url = yield self.build.getUrl()
         self.assertEqual(url, 'http://localhost:8080/#builders/108/builds/33')
@@ -962,7 +987,7 @@ class TestBuildBlameList(unittest.TestCase):
         self.assertEqual(blamelist, [])
 
 
-class TestSetupProperties_MultipleSources(unittest.TestCase):
+class TestSetupProperties_MultipleSources(TestReactorMixin, unittest.TestCase):
 
     """
     Test that the property values, based on the available requests, are
@@ -970,6 +995,7 @@ class TestSetupProperties_MultipleSources(unittest.TestCase):
     """
 
     def setUp(self):
+        self.setUpTestReactor()
         self.props = {}
         r = FakeRequest()
         r.sources = []
@@ -986,8 +1012,7 @@ class TestSetupProperties_MultipleSources(unittest.TestCase):
         r.sources[1].revision = "34567"
         self.build = Build([r])
         self.build.setStepFactories([])
-        self.builder = FakeBuilder(
-            fakemaster.make_master(wantData=True, testcase=self))
+        self.builder = FakeBuilder(fakemaster.make_master(self, wantData=True))
         self.build.setBuilder(self.builder)
         self.build.build_status = FakeBuildStatus()
         # record properties that will be set
@@ -1009,7 +1034,7 @@ class TestSetupProperties_MultipleSources(unittest.TestCase):
         self.assertNotIn("repository", self.props["Build"])
 
 
-class TestSetupProperties_SingleSource(unittest.TestCase):
+class TestSetupProperties_SingleSource(TestReactorMixin, unittest.TestCase):
 
     """
     Test that the property values, based on the available requests, are
@@ -1017,6 +1042,7 @@ class TestSetupProperties_SingleSource(unittest.TestCase):
     """
 
     def setUp(self):
+        self.setUpTestReactor()
         self.props = {}
         r = FakeRequest()
         r.sources = []
@@ -1028,8 +1054,7 @@ class TestSetupProperties_SingleSource(unittest.TestCase):
         r.sources[0].revision = "12345"
         self.build = Build([r])
         self.build.setStepFactories([])
-        self.builder = FakeBuilder(
-            fakemaster.make_master(wantData=True, testcase=self))
+        self.builder = FakeBuilder(fakemaster.make_master(self, wantData=True))
         self.build.setBuilder(self.builder)
         self.build.build_status = FakeBuildStatus()
         # record properties that will be set
@@ -1068,7 +1093,7 @@ class TestSetupProperties_SingleSource(unittest.TestCase):
         self.assertEqual(project, '')
 
 
-class TestBuildProperties(unittest.TestCase):
+class TestBuildProperties(TestReactorMixin, unittest.TestCase):
 
     """
     Test that a Build has the necessary L{IProperties} methods, and that they
@@ -1077,6 +1102,8 @@ class TestBuildProperties(unittest.TestCase):
     """
 
     def setUp(self):
+        self.setUpTestReactor()
+
         @implementer(interfaces.IProperties)
         class FakeProperties(Mock):
             pass
@@ -1088,15 +1115,14 @@ class TestBuildProperties(unittest.TestCase):
         r.sources = [FakeSource()]
         r.sources[0].changes = [FakeChange()]
         r.sources[0].revision = "12345"
-        self.master = fakemaster.make_master(wantData=True, testcase=self)
+        self.master = fakemaster.make_master(self, wantData=True)
         self.worker = worker.FakeWorker(self.master)
         self.worker.attached(None)
         self.workerforbuilder = Mock(name='workerforbuilder')
         self.workerforbuilder.worker = self.worker
         self.build = Build([r])
         self.build.setStepFactories([])
-        self.builder = FakeBuilder(
-            fakemaster.make_master(wantData=True, testcase=self))
+        self.builder = FakeBuilder(fakemaster.make_master(self, wantData=True))
         self.build.setBuilder(self.builder)
         self.properties = self.build.properties = FakeProperties()
         self.build_status = FakeBuildStatus()
