@@ -26,6 +26,7 @@ from buildbot.process import buildrequestdistributor
 from buildbot.process import factory
 from buildbot.test.fake import fakedb
 from buildbot.test.fake import fakemaster
+from buildbot.test.util.misc import TestReactorMixin
 from buildbot.test.util.warnings import assertProducesWarning
 from buildbot.util import epoch2datetime
 from buildbot.util.eventual import fireEventually
@@ -41,9 +42,10 @@ def nth_worker(n):
     return pick_nth_by_name
 
 
-class TestBRDBase(unittest.TestCase):
+class TestBRDBase(TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         self.botmaster = mock.Mock(name='botmaster')
         self.botmaster.builders = {}
         self.builders = {}
@@ -51,8 +53,8 @@ class TestBRDBase(unittest.TestCase):
         def prioritizeBuilders(master, builders):
             # simple sort-by-name by default
             return sorted(builders, key=lambda b1: b1.name)
-        self.master = self.botmaster.master = fakemaster.make_master(testcase=self,
-                                                                     wantData=True, wantDb=True)
+        self.master = self.botmaster.master = \
+            fakemaster.make_master(self, wantData=True, wantDb=True)
         self.master.caches = fakemaster.FakeCaches()
         self.master.config.prioritizeBuilders = prioritizeBuilders
         self.brd = buildrequestdistributor.BuildRequestDistributor(
@@ -394,7 +396,7 @@ class TestMaybeStartBuilds(TestBRDBase):
         self.assertBuildsStarted(exp_builds)
 
     @defer.inlineCallbacks
-    def test_no_buildreqests(self):
+    def test_no_buildrequests(self):
         self.addWorkers({'test-worker11': 1})
         yield self.do_test_maybeStartBuildsOnBuilder(exp_claims=[], exp_builds=[])
 
@@ -701,7 +703,7 @@ class TestMaybeStartBuilds(TestBRDBase):
         # fake a race condition on the buildrequests table
         old_claimBuildRequests = self.master.db.buildrequests.claimBuildRequests
 
-        def claimBuildRequests(brids, claimed_at=None, _reactor=None):
+        def claimBuildRequests(brids, claimed_at=None):
             # first, ensure this only happens the first time
             self.master.db.buildrequests.claimBuildRequests = old_claimBuildRequests
             # claim brid 10 for some other master
