@@ -27,8 +27,12 @@ from twisted.trial import unittest
 from twisted.web.resource import Resource
 from twisted.web.server import Site
 
+from buildbot.process.properties import Secret
+from buildbot.secrets.manager import SecretManager
+from buildbot.test.fake.secrets import FakeSecretStorage
 from buildbot.test.util import www
 from buildbot.test.util.config import ConfigErrorsMixin
+from buildbot.test.util.misc import TestReactorMixin
 from buildbot.util import bytes2unicode
 
 try:
@@ -51,9 +55,11 @@ class FakeResponse:
         pass
 
 
-class OAuth2Auth(www.WwwTestMixin, ConfigErrorsMixin, unittest.TestCase):
+class OAuth2Auth(TestReactorMixin, www.WwwTestMixin, ConfigErrorsMixin,
+                 unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         if requests is None:
             raise unittest.SkipTest("Need to install requests to test oauth2")
 
@@ -78,6 +84,17 @@ class OAuth2Auth(www.WwwTestMixin, ConfigErrorsMixin, unittest.TestCase):
             self._master = master = self.make_master(url='h:/a/b/', auth=auth)
             auth.reconfigAuth(master, master.config)
 
+        self.githubAuth_secret = oauth2.GitHubAuth(
+            Secret("client-id"), Secret("client-secret"), apiVersion=4)
+        self._master = master = self.make_master(url='h:/a/b/', auth=auth)
+        fake_storage_service = FakeSecretStorage()
+        fake_storage_service.reconfigService(secretdict={"client-id": "secretClientId",
+                                                         "client-secret": "secretClientSecret"})
+        secret_service = SecretManager()
+        secret_service.services = [fake_storage_service]
+        secret_service.setServiceParent(self._master)
+        self.githubAuth_secret.reconfigAuth(master, master.config)
+
     @defer.inlineCallbacks
     def test_getGoogleLoginURL(self):
         res = yield self.googleAuth.getLoginURL('http://redir')
@@ -109,6 +126,20 @@ class OAuth2Auth(www.WwwTestMixin, ConfigErrorsMixin, unittest.TestCase):
                "scope=user%3Aemail+read%3Aorg")
         self.assertEqual(res, exp)
 
+    @defer.inlineCallbacks
+    def test_getGithubLoginURL_with_secret(self):
+        res = yield self.githubAuth_secret.getLoginURL('http://redir')
+        exp = ("https://github.com/login/oauth/authorize?client_id=secretClientId&"
+               "redirect_uri=h%3A%2Fa%2Fb%2Fauth%2Flogin&response_type=code&"
+               "scope=user%3Aemail+read%3Aorg&"
+               "state=redirect%3Dhttp%253A%252F%252Fredir")
+        self.assertEqual(res, exp)
+        res = yield self.githubAuth_secret.getLoginURL(None)
+        exp = ("https://github.com/login/oauth/authorize?client_id=secretClientId&"
+               "redirect_uri=h%3A%2Fa%2Fb%2Fauth%2Flogin&response_type=code&"
+               "scope=user%3Aemail+read%3Aorg")
+        self.assertEqual(res, exp)
+
     @defer.inlineCallbacks
     def test_getGithubELoginURL(self):
         res = yield self.githubAuthEnt.getLoginURL('http://redir')
@@ -191,30 +222,7 @@ class OAuth2Auth(www.WwwTestMixin, ConfigErrorsMixin, unittest.TestCase):
                           'full_name': 'foo bar'}, res)
 
     @defer.inlineCallbacks
-    def test_GithubAcceptToken(self):
-        requests.get.side_effect = []
-        requests.post.side_effect = [
-            FakeResponse(dict(access_token="TOK3N"))]
-        self.githubAuth.get = mock.Mock(side_effect=[
-            dict(  # /user
-                login="bar",
-                name="foo bar",
-                email="buzz@bar"),
-            [  # /user/emails
-                {'email': 'buzz@bar', 'verified': True, 'primary': False},
-                {'email': 'bar@foo', 'verified': True, 'primary': True}],
-            [  # /user/orgs
-                dict(login="hello"),
-                dict(login="grp"),
-            ]])
-        res = yield self.githubAuth.acceptToken("TOK3N")
-        self.assertEqual({'email': 'bar@foo',
-                          'username': 'bar',
-                          'groups': ["hello", "grp"],
-                          'full_name': 'foo bar'}, res)
-
-    @defer.inlineCallbacks
-    def test_GithubAcceptToken_v4(self):
+    def test_GithubVerifyCode_v4(self):
         requests.get.side_effect = []
         requests.post.side_effect = [
             FakeResponse(dict(access_token="TOK3N"))]
@@ -243,14 +251,14 @@ class OAuth2Auth(www.WwwTestMixin, ConfigErrorsMixin, unittest.TestCase):
                 }
             }
         ])
-        res = yield self.githubAuth_v4.acceptToken("TOK3N")
+        res = yield self.githubAuth_v4.verifyCode("code!")
         self.assertEqual({'email': 'bar@foo',
                           'username': 'bar',
                           'groups': ["hello", "grp"],
                           'full_name': 'foo bar'}, res)
 
     @defer.inlineCallbacks
-    def test_GithubAcceptToken_v4_teams(self):
+    def test_GithubVerifyCode_v4_teams(self):
         requests.get.side_effect = []
         requests.post.side_effect = [
             FakeResponse(dict(access_token="TOK3N"))]
@@ -331,7 +339,7 @@ class OAuth2Auth(www.WwwTestMixin, ConfigErrorsMixin, unittest.TestCase):
                 }
             }
         ])
-        res = yield self.githubAuth_v4_teams.acceptToken("TOK3N")
+        res = yield self.githubAuth_v4_teams.verifyCode("code!")
         self.assertEqual({'email': 'bar@foo',
                           'username': 'bar',
                           'groups': [
@@ -434,11 +442,9 @@ class OAuth2Auth(www.WwwTestMixin, ConfigErrorsMixin, unittest.TestCase):
         rsrc.auth.verifyCode.assert_called_once_with(b"code!")
         self.assertEqual(self.master.session.user_info, {'username': 'bar'})
         self.assertEqual(res, {'redirected': b'://me'})
+        # token not supported anymore
         res = yield self.render_resource(rsrc, b'/?token=token!')
-        rsrc.auth.getLoginURL.assert_not_called()
-        rsrc.auth.acceptToken.assert_called_once_with(b"token!")
-        self.assertEqual(self.master.session.user_info, {'username': 'bar'})
-        self.assertEqual(res, {'redirected': b'://me'})
+        rsrc.auth.getLoginURL.assert_called_once()
 
     def test_getConfig(self):
         self.assertEqual(self.githubAuth.getConfigDict(), {'fa_icon': 'fa-github', 'autologin': False,
@@ -473,13 +479,16 @@ class OAuth2Auth(www.WwwTestMixin, ConfigErrorsMixin, unittest.TestCase):
 #  }
 
 
-class OAuth2AuthGitHubE2E(www.WwwTestMixin, unittest.TestCase):
+class OAuth2AuthGitHubE2E(TestReactorMixin, www.WwwTestMixin,
+                          unittest.TestCase):
     authClass = "GitHubAuth"
 
     def _instantiateAuth(self, cls, config):
         return cls(config["CLIENTID"], config["CLIENTSECRET"])
 
     def setUp(self):
+        self.setUpTestReactor()
+
         if requests is None:
             raise unittest.SkipTest("Need to install requests to test oauth2")
 
