@@ -13,33 +13,25 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
-import os
 import shutil
+import tempfile
 
 
-class PrivateTemporaryDirectory(object):
+class PrivateTemporaryDirectory:
     """ Works similarly to python 3.2+ TemporaryDirectory except the
-        permissions and the exact path are given to the class.
-
-        TODO: Use TemporaryDirectory when python 2.x is dropped
+        also sets the permissions of the created directory and
 
         Note, that Windows ignores the permissions.
     """
 
-    def __init__(self, name, mode=0o700):
-        self.name = name
+    def __init__(self, suffix=None, prefix=None, dir=None, mode=0o700):
+        self.name = tempfile.mkdtemp(suffix, prefix, dir)
         self.mode = mode
         self._cleanup_needed = True
 
-    def _create_dir(self, name, mode):
-        os.makedirs(name, mode=mode)
-
     def __enter__(self):
-        self._create_dir(self.name, self.mode)
-        return self
+        return self.name
 
     def __exit__(self, exc, value, tb):
         self.cleanup()
